@@ -4,7 +4,7 @@ use Modern::Perl;
 use Readonly;
 use Scalar::Util 'reftype';
 
-our $VERSION = q/1.14/;
+our $VERSION = '1.16';
 
 # Exporter
 Readonly our @EXPORT      => qw(jsdump hjsdump);
@@ -22,7 +22,7 @@ Readonly my $JSCOMPAT_UNDEFINED_MISSING    => 1.2;
 # This is a context variable which holds on to configs.
 my %opt = ( JS => $JSCOMPAT_DEFAULT_VERSION );  # TODO: This is super out-dated.
 
-if ( !$] < $MIN_ENCODE_REQUIRE_BREAKPOINT ) { require Encode; }
+if ( $] >= $MIN_ENCODE_REQUIRE_BREAKPOINT ) { require Encode; }
 
 sub import {
   my ( $package, @args ) = @_;
@@ -32,6 +32,7 @@ sub import {
   my @import           = ();
   my %allowable        = map { $_ => 1 } ( @EXPORT, @EXPORT_OK );
 
+  # This is the madness for the JS version
   for my $arg (@args) {
     if ( ref $arg eq 'HASH' ) {
       if ( exists $arg->{JS} )    { $opt{JS}    = $arg->{JS}; }
@@ -104,7 +105,6 @@ sub jsdump {
   return wantarray ? @res : join qq/\n/, @res, q//;
 }
 
-## RJEWKno critic (RequireCheckingReturnValueOfEval, RequireInterpolationOfMetachars, ProhibitStringyEval)
 sub __quotemeta {
   my ($input) = @_;
 
@@ -156,27 +156,25 @@ sub __jsdump {
 
   if ( not $ref ) {
     if ( not defined $elem ) {
-      return qq/$sym = @{[defined($undef) ? $undef : $opt{UNDEF}]};/;
+      return qq($sym = @{[defined($undef) ? $undef : $opt{UNDEF}]};);
     }
 
     #Translated from $Regexp::Common::RE{num}{real}
-    if ( $elem =~ /^[+-]?(?:(?=\d|[.])\d*(?:[.]\d{0,})?)$/xsm ) {
+    if ( $elem ne '.' &&
+	 $elem =~ /^[+-]?(?:(?=\d|[.])\d*(?:[.]\d{0,})?)(?:[eE][+-]?\d+)?$/xsm ) {
 
-      #                                                      (?:[eE][+-]?\d+)?
-      if ( $elem =~ /^0\d+$/xsm ) {
-        return qq/$sym = "$elem";/;
-      }
-      return qq/$sym = $elem;/;
+      if( $elem =~ /^0\d+$/xsm ){
+        return qq($sym = "$elem";) }
+      return qq($sym = $elem;);
     }
 
     #Fall-back to quoted string
-    return qq/$sym = "/ . __quotemeta($elem) . q/";/;
+    return qq($sym = ") . __quotemeta($elem) . '";';
   }
 
   #Circular references
-  if ( $dict->{$elem} ) {
-    return qq/$sym = $dict->{$elem};/;
-  }
+  if( $dict->{$elem} ){
+    return qq($sym = $dict->{$elem};) }
   $dict->{$elem} = $sym;
 
   #isa over ref in case we're given objects
@@ -215,11 +213,14 @@ Data::JavaScript - Dump perl data structures into JavaScript code
 
 =head1 SYNOPSIS
 
-  use Data::JavaScript;                     # Use defaults
+  # Compatibility mode
+  {
+    use Data::JavaScript;                     # Use defaults
   
-  @code =  jsdump('my_array',  $array_ref); # Return array for formatting
-  $code =  jsdump('my_object', $hash_ref);  # Return convenient string
-  $html = hjsdump('my_stuff',  $reference); # Convenience wrapper
+    my @code =  jsdump('my_array',  $array_ref); # Return array for formatting
+    my $code =  jsdump('my_object', $hash_ref);  # Return convenient string
+    my $html = hjsdump('my_stuff',  $reference); # Convenience wrapper
+  };
 
 =head1 DESCRIPTION
 
